@@ -528,6 +528,7 @@ void Handler::requestScan(const QString &interface)
                 }
 
                 qCDebug(PLASMA_NM_LIBS_LOG) << "Requesting wifi scan on device" << wifiDevice->interfaceName();
+                incrementScansCount();
                 QDBusPendingReply<> reply = wifiDevice->requestScan();
                 auto watcher = new QDBusPendingCallWatcher(reply, this);
                 watcher->setProperty("action", Handler::RequestScan);
@@ -538,6 +539,26 @@ void Handler::requestScan(const QString &interface)
     }
 }
 
+void Handler::incrementScansCount()
+{
+    m_ongoingScansCount += 1;
+    if (m_ongoingScansCount == 1) {
+        Q_EMIT scanningChanged();
+    }
+}
+
+void Handler::decrementScansCount()
+{
+    if (m_ongoingScansCount == 0) {
+        qCDebug(PLASMA_NM_LIBS_LOG) << "Extra decrementScansCount() called";
+        return;
+    }
+    m_ongoingScansCount -= 1;
+    if (m_ongoingScansCount == 0) {
+        Q_EMIT scanningChanged();
+    }
+}
+
 void Handler::createHotspot()
 {
     bool foundInactive = false;
@@ -657,7 +678,7 @@ bool Handler::checkRequestScanRateLimit(const NetworkManager::WirelessDevice::Pt
     ret |= lastRequestScan.isValid() && lastRequestScan.msecsTo(now) < NM_REQUESTSCAN_LIMIT_RATE;
     // skip the request scan
     if (ret) {
-        qCDebug(PLASMA_NM_LIBS_LOG) << "Last scan finished " << lastScan.msecsTo(now) << "ms ago and last request scan was sent "
+        qCDebug(PLASMA_NM_LIBS_LOG) << "Last scan finished" << lastScan.msecsTo(now) << "ms ago and last request scan was sent" //
                                     << lastRequestScan.msecsTo(now) << "ms ago, Skipping scanning interface:" << wifiDevice->interfaceName();
         return false;
     }
@@ -772,6 +793,7 @@ void Handler::replyFinished(QDBusPendingCallWatcher *watcher)
             const QString interface = watcher->property("interface").toString();
             qCWarning(PLASMA_NM_LIBS_LOG) << "Wireless scan on" << interface << "failed:" << error;
             scanRequestFailed(interface);
+            decrementScansCount();
             break;
         }
         case Handler::CreateHotspot:
@@ -807,6 +829,7 @@ void Handler::replyFinished(QDBusPendingCallWatcher *watcher)
             break;
         case Handler::RequestScan:
             qCDebug(PLASMA_NM_LIBS_LOG) << "Wireless scan on" << watcher->property("interface").toString() << "succeeded";
+            decrementScansCount();
             break;
         default:
             break;
